# Devices

## QEMU devices

The following QEMU devices are currently supported by TuxTest:

* qemu-arm64
* qemu-arm64be
* qemu-armv5
* qemu-armv7
* qemu-armv7be
* qemu-i386
* qemu-mips32
* qemu-mips32el
* qemu-mips64
* qemu-mips64el
* qemu-ppc32
* qemu-ppc64
* qemu-ppc64le
* qemu-riscv64
* qemu-s390
* qemu-sh4
* qemu-sparc64
* qemu-x86_64

In order to be compatible with build architectures, the following aliases are also recognised:

* qemu-arm: qemu-armv7
* qemu-mips: qemu-mips64
* qemu-powerpc: qemu-ppc64
* qemu-riscv: qemu-riscv64

## FVP devices

The following FVP devices are currently supported by TuxTest:

* fvp-aemva
* fvp-morello-android
* fvp-morello-busybox
* fvp-morello-baremetal
* fvp-morello-oe
* fvp-morello-ubuntu
